package com.zulong.sdk.plugin;

import android.app.Application;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.net.Uri;
import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;

import com.adjust.sdk.Adjust;
import com.adjust.sdk.AdjustAttribution;
import com.adjust.sdk.AdjustConfig;
import com.adjust.sdk.AdjustEventFailure;
import com.adjust.sdk.AdjustEventSuccess;
import com.adjust.sdk.AdjustSessionFailure;
import com.adjust.sdk.AdjustSessionSuccess;
import com.adjust.sdk.LogLevel;
import com.adjust.sdk.OnAttributionChangedListener;
import com.adjust.sdk.OnDeeplinkResponseListener;
import com.adjust.sdk.OnEventTrackingFailedListener;
import com.adjust.sdk.OnEventTrackingSucceededListener;
import com.adjust.sdk.OnSessionTrackingFailedListener;
import com.adjust.sdk.OnSessionTrackingSucceededListener;
import com.appsflyer.AppsFlyerConversionListener;
import com.appsflyer.AppsFlyerLib;
import com.kochava.base.Tracker;
import com.zulong.sharesdk.ZLThirdParty;

import java.util.Map;

/**
 * Created by Administrator on 2016/11/4.
 */

public class ZLSDKApplication extends Application {
    private static final String TAG = "ZLSDKApplication";

    @Override
    public void onCreate() {
        super.onCreate();
        Log.e(TAG, "ZLThirdParty ApplicationOnCreate!");
        ZLThirdParty.getInstance().ApplicationOnCreate(this);
        //初始化kochava
        String kochavaIdStr = "";
        try {
            ApplicationInfo appInfo = this.getPackageManager().getApplicationInfo(getPackageName(),PackageManager.GET_META_DATA);
            kochavaIdStr = appInfo.metaData.getString("kochavaId");
            if (null != kochavaIdStr && !TextUtils.isEmpty(kochavaIdStr)) {
                Log.e(TAG, "kochava start Tracker configure !");
                Tracker.configure(new Tracker.Configuration(this).setAppGuid(kochavaIdStr).setLogLevel(Tracker.LOG_LEVEL_DEBUG));
            }else {
                throw new Exception();
            }
        } catch (Exception e) {
            Log.e("UnisdkZuLongApplication", "sdk初始化失败，读取kochavaId错误！");
            Toast.makeText(this.getApplicationContext(), "sdk初始化失败，读取kochavaId错误！", Toast.LENGTH_SHORT).show();
        }
        //初始化adjust
        String adjustToken = "";
        try {
            ApplicationInfo appInfo = this.getPackageManager().getApplicationInfo(getPackageName(),PackageManager.GET_META_DATA);
            adjustToken = appInfo.metaData.getString("adjustToken");
            String adjustModel = appInfo.metaData.getString("adjustModel");
            if (null != adjustToken && !TextUtils.isEmpty(adjustToken)) {
                String environment = "";
                if (adjustModel != null && adjustModel.matches("sandbox")) {
                    environment = AdjustConfig.ENVIRONMENT_SANDBOX;
                }else {
                    environment = AdjustConfig.ENVIRONMENT_PRODUCTION;
                }
                AdjustConfig config = new AdjustConfig(this, adjustToken, environment);
                config.setLogLevel(LogLevel.VERBOSE);
                // Set attribution delegate.
                config.setOnAttributionChangedListener(new OnAttributionChangedListener() {
                    @Override
                    public void onAttributionChanged(AdjustAttribution attribution) {
                        Log.d(TAG, "adjust Attribution callback called!");
                        Log.d(TAG, "adjust Attribution: " + attribution.toString());
                    }
                });

                // Set event success tracking delegate.
                config.setOnEventTrackingSucceededListener(new OnEventTrackingSucceededListener() {
                    @Override
                    public void onFinishedEventTrackingSucceeded(AdjustEventSuccess eventSuccessResponseData) {
                        Log.d(TAG, "adjust Event success callback called!");
                        Log.d(TAG, "adjust Event success data: " + eventSuccessResponseData.toString());
                    }
                });

                // Set event failure tracking delegate.
                config.setOnEventTrackingFailedListener(new OnEventTrackingFailedListener() {
                    @Override
                    public void onFinishedEventTrackingFailed(AdjustEventFailure eventFailureResponseData) {
                        Log.d(TAG, "adjust Event failure callback called!");
                        Log.d(TAG, "adjust Event failure data: " + eventFailureResponseData.toString());
                    }
                });

                // Set session success tracking delegate.
                config.setOnSessionTrackingSucceededListener(new OnSessionTrackingSucceededListener() {
                    @Override
                    public void onFinishedSessionTrackingSucceeded(AdjustSessionSuccess sessionSuccessResponseData) {
                        Log.d(TAG, "adjust Session success callback called!");
                        Log.d(TAG, "adjust Session success data: " + sessionSuccessResponseData.toString());
                    }
                });

                // Set session failure tracking delegate.
                config.setOnSessionTrackingFailedListener(new OnSessionTrackingFailedListener() {
                    @Override
                    public void onFinishedSessionTrackingFailed(AdjustSessionFailure sessionFailureResponseData) {
                        Log.d(TAG, "adjust Session failure callback called!");
                        Log.d(TAG, "adjust Session failure data: " + sessionFailureResponseData.toString());
                    }
                });

                // Evaluate deferred deep link to be launched.
                config.setOnDeeplinkResponseListener(new OnDeeplinkResponseListener() {
                    @Override
                    public boolean launchReceivedDeeplink(Uri deeplink) {
                        Log.d(TAG, "adjust Deferred deep link callback called!");
                        Log.d(TAG, "adjust Deep link URL: " + deeplink);

                        return true;
                    }
                });

                config.setSendInBackground(true);
//		        config.setEventBufferingEnabled(true);//累计一分钟发送一次
                Adjust.onCreate(config);
            }else {
                Log.e(TAG, "读取adjustToken错误！不 使用adjust数据上报功能！");
            }
        } catch (Exception e) {
            Log.e(TAG, "sdk初始化失败，读取adjustToken错误！");
            Toast.makeText(this.getApplicationContext(), "sdk初始化失败，读取adjustToken错误！", Toast.LENGTH_SHORT).show();
        }


        //初始化kochava
        String appsFlyerKey = "";
        try {
            ApplicationInfo appInfo = this.getPackageManager().getApplicationInfo(getPackageName(),PackageManager.GET_META_DATA);
            appsFlyerKey = appInfo.metaData.getString("appsFlyerKey");
            if (null != appsFlyerKey && !TextUtils.isEmpty(appsFlyerKey)) {
                AppsFlyerLib.getInstance().init(appsFlyerKey, new AppsFlyerConversionListener() {

                    @Override
                    public void onInstallConversionDataLoaded(Map<String, String> conversionData) {
                        //安装成功信息
                        for (String attrName : conversionData.keySet()) {
                            Log.e(AppsFlyerLib.LOG_TAG, "attribute: " + attrName + " = " + conversionData.get(attrName));
                        }
                    }

                    @Override
                    public void onInstallConversionFailure(String errorMessage) {
                        //安装失败信息
                        Log.e(AppsFlyerLib.LOG_TAG, "error getting conversion data: " + errorMessage);
                    }

                    /* Called only when a Deep Link is opened */
                    @Override
                    public void onAppOpenAttribution(Map<String, String> conversionData) {
                        //上传成功信息
                        for (String attrName : conversionData.keySet()) {
                            Log.e(AppsFlyerLib.LOG_TAG, "attribute: " + attrName + " = " + conversionData.get(attrName));
                        }
                    }

                    @Override
                    public void onAttributionFailure(String errorMessage) {
                        //上传失败信息
                        Log.e(AppsFlyerLib.LOG_TAG, "error onAttributionFailure : " + errorMessage);
                    }
                });
                AppsFlyerLib.getInstance().startTracking(this);
//				AppsFlyerLib.getInstance().setDebugLog(true);//debug模式，在发布包去掉
            }else {
                Log.e("UnisdkZuLongApplication", "读取appsFlyerKey错误！ 不使用appsFlyer数据上报功能！");
            }
        } catch (Exception e) {
            Log.e("UnisdkZuLongApplication", "sdk初始化失败，读取appsFlyerKey错误！");
            Toast.makeText(this.getApplicationContext(), "sdk初始化失败，读取appsFlyerKey错误！", Toast.LENGTH_SHORT).show();
        }
    }
}
